<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Observer for grade and grade items changes in other activities.
 * @package    mod_randomactivity
 * @copyright  Astor Bizard, 2020
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace mod_randomactivity;
defined('MOODLE_INTERNAL') || die();

global $CFG;
require_once($CFG->dirroot . '/mod/randomactivity/locallib.php');
require_once($CFG->dirroot . '/mod/randomactivity/lib.php');

/**
 * Grade observer definition.
 * @copyright  Astor Bizard, 2020
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class grade_observer {
    /**
     * Observer called every time an activity grade or grade item changes.
     * Updates Random activities grades and grade items accordingly.
     * @param \core\event\user_graded $event
     */
    public static function user_activity_graded(\core\event\user_graded $event) {
        global $DB;
        $grade = $event->get_grade();
        $gradeitem = $grade->grade_item;
        $courseid = $gradeitem->courseid;
        $userid = $grade->userid;

        if ($gradeitem->itemtype == 'mod' && $gradeitem->itemmodule != 'randomactivity') {
            $randomactivities = get_fast_modinfo($courseid, -1)->get_instances_of('randomactivity');
            $gradedcm = get_fast_modinfo($courseid, -1)->get_instances_of($gradeitem->itemmodule)[$gradeitem->iteminstance];
            foreach ($randomactivities as $cminfo) {
                $modinstance = $DB->get_record('randomactivity', array( 'id' => $cminfo->instance ));
                if ($modinstance->grade != 0 && ($modinstance->duedate == 0 || $modinstance->duedate >= time())) {
                    $cmid = randomactivity_get_assigned_activity($cminfo, $modinstance->activities, $userid, $modinstance->seed);
                    if ($cmid == $gradedcm->id) {
                        randomactivity_update_grade($modinstance, $userid, $grade);
                    }
                }
            }
        }
    }
}
